% initialise
clear all
close all

%% load data
coordinates = load('coordinates.dat');
bdry = load('bdry.dat');
data = load('elements.dat');
elements = data(:,1:2);

H = data(:,3)/100; % scale to [m]
W = data(:,4)/100; % scale to [m]

E = 2e+8;   % elasticity module [N/m^2]
NU = 0.3;   % Poisson ratio
RHO = 8250; % specific weight   [kg/m^3]

%% Plot coordinates and elements
f1 = figure('Position',[50,50,400,600],'PaperUnits','points',...
            'PaperPositionMode','manual');
axes1 = axes('Parent',f1,'Position',[0.13 0.01 0.775 0.9]);
axis tight
set(gca,'nextplot','replacechildren');

edges  = [coordinates(elements(1:end,1),:).';
          coordinates(elements(1:end,2),:).'];
plot3([edges(1,:);edges(4,:)], ...
      [edges(2,:);edges(5,:)], ...
      [edges(3,:);edges(6,:)],'k-');
    hold on
axis equal
view(60,20)
xlim([-15,15])
ylim([-15,15])
zlim([-50,0])

    
%% Assemble Stiffness- and Mass-Matrix
[A,B] = assemble(coordinates, elements, H, W, E, NU, RHO);
figure(2)
spy(A)

% consider bdry --> determine freenodes
freenodes = 1:6*size(coordinates,1);
for j=1:length(bdry)
  freenodes = setdiff(freenodes,6*bdry(j)-[5:-1:0]);
end

A = A(freenodes,freenodes); 
B = B(freenodes,freenodes);

% compute eigenvalues
[EV,EW] = eig(B\A);
[i,ind] = sort(abs(diag(EW)));

% select k'th largest eigenvalue
k = 4;
u = zeros(6*size(coordinates,1),1);
u(freenodes) = EV(:,ind(k));

scal = 8; % scaling factor
u = [u(1:6:end),u(2:6:end),u(3:6:end)];
u = scal*u./max(max(abs(u)));



%% Display Results
nFrames = 701;
phi = linspace(0,10*pi,nFrames);
t =sin(phi);
phi1 =0;
%aviobj = avifile('eig4.avi', 'fps',30);
for ell = 1: nFrames

% plot edges and vertices
% plot3(coordinates(:,1), ...
%       coordinates(:,2), ...
%       coordinates(:,3),'k.');
% hold on
% for j=1:size(elements,1)
%   plot3(coordinates(elements(j,:),1), ...
%         coordinates(elements(j,:),2), ...
%         coordinates(elements(j,:),3),'-k','LineWidth',2);
% end
% axis off
% for j=1:size(elements,1)
%     plot3(coord(elements(j,:),1), ...
%           coord(elements(j,:),2), ...
%           coord(elements(j,:),3),'r-');
%         hold on
% end
figure(1)
clf
edges  = [coordinates(elements(1:end,1),:).';
          coordinates(elements(1:end,2),:).'];
plot3([edges(1,:);edges(4,:)], ...
      [edges(2,:);edges(5,:)], ...
      [edges(3,:);edges(6,:)],'k-');

coords = coordinates + t(ell)*u;
edges  = [coords(elements(1:end,1),:).';coords(elements(1:end,2),:).'];
hold on
plot3([edges(1,:);edges(4,:)], [edges(2,:);edges(5,:)], [edges(3,:);edges(6,:)],'r-');
hold off
axis equal
axis off

xlim([-10,10])
ylim([-10,10])
zlim([-50,2])

campos([20*cos(phi1), 20*sin(phi1), -20])
title({'Bantle/Funken','Universitaet Ulm'})
drawnow

% scrpos=get(gcf,'Position');
% newpos=scrpos/100;
% set(gcf,'PaperUnits','inches','PaperPosition',newpos);

% eval(['print -dpng -r100 ',num2str(ell),'.png'])


%F(ell) = getframe(f1);
%aviobj = addframe(aviobj,F(ell));

phi1 = phi1+2*pi/(nFrames-1); 

end

% aviobj = close(aviobj);
% 
% hf = figure; 
% set(hf, 'position', [1,1,600,800]);
% movie(hf,F(1:1:end),4,30);

